Documentation
¶
Overview ¶
Package v1alpha2 contains API Schema definitions for the certmanager v1alpha2 API group +kubebuilder:object:generate=true +groupName=certmanager.puppetca
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "certmanager.puppetca", Version: "v1alpha2"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ConditionStatus ¶
type ConditionStatus string
ConditionStatus represents a condition's status. +kubebuilder:validation:Enum=True;False;Unknown
const ( // ConditionTrue represents the fact that a given condition is true ConditionTrue ConditionStatus = "True" // ConditionFalse represents the fact that a given condition is false ConditionFalse ConditionStatus = "False" // ConditionUnknown represents the fact that a given condition is unknown ConditionUnknown ConditionStatus = "Unknown" )
These are valid condition statuses. "ConditionTrue" means a resource is in the condition; "ConditionFalse" means a resource is not in the condition; "ConditionUnknown" means kubernetes can't decide if a resource is in the condition or not. In the future, we could add other intermediate conditions, e.g. ConditionDegraded.
type ConditionType ¶
type ConditionType string
ConditionType represents a PuppetCAIssuer condition type. +kubebuilder:validation:Enum=Ready
const ( // ConditionReady indicates that a PuppetCAIssuer is ready for use. ConditionReady ConditionType = "Ready" )
type PuppetCAIssuer ¶
type PuppetCAIssuer struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PuppetCAIssuerSpec `json:"spec,omitempty"`
Status PuppetCAIssuerStatus `json:"status,omitempty"`
}
PuppetCAIssuer is the Schema for the puppetcaissuers API +kubebuilder:subresource:status
func (*PuppetCAIssuer) DeepCopy ¶
func (in *PuppetCAIssuer) DeepCopy() *PuppetCAIssuer
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAIssuer.
func (*PuppetCAIssuer) DeepCopyInto ¶
func (in *PuppetCAIssuer) DeepCopyInto(out *PuppetCAIssuer)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PuppetCAIssuer) DeepCopyObject ¶
func (in *PuppetCAIssuer) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PuppetCAIssuerCondition ¶
type PuppetCAIssuerCondition struct {
// Type of the condition, currently ('Ready').
Type ConditionType `json:"type"`
// Status of the condition, one of ('True', 'False', 'Unknown').
// +kubebuilder:validation:Enum=True;False;Unknown
Status ConditionStatus `json:"status"`
// LastTransitionTime is the timestamp corresponding to the last status
// change of this condition.
// +optional
LastTransitionTime *metav1.Time `json:"lastTransitionTime,omitempty"`
// Reason is a brief machine readable explanation for the condition's last
// transition.
// +optional
Reason string `json:"reason,omitempty"`
// Message is a human readable description of the details of the last
// transition, complementing reason.
// +optional
Message string `json:"message,omitempty"`
}
PuppetCAIssuerCondition contains condition information for the issuer.
func (*PuppetCAIssuerCondition) DeepCopy ¶
func (in *PuppetCAIssuerCondition) DeepCopy() *PuppetCAIssuerCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAIssuerCondition.
func (*PuppetCAIssuerCondition) DeepCopyInto ¶
func (in *PuppetCAIssuerCondition) DeepCopyInto(out *PuppetCAIssuerCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PuppetCAIssuerList ¶
type PuppetCAIssuerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []PuppetCAIssuer `json:"items"`
}
PuppetCAIssuerList contains a list of PuppetCAIssuer
func (*PuppetCAIssuerList) DeepCopy ¶
func (in *PuppetCAIssuerList) DeepCopy() *PuppetCAIssuerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAIssuerList.
func (*PuppetCAIssuerList) DeepCopyInto ¶
func (in *PuppetCAIssuerList) DeepCopyInto(out *PuppetCAIssuerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PuppetCAIssuerList) DeepCopyObject ¶
func (in *PuppetCAIssuerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PuppetCAIssuerSpec ¶
type PuppetCAIssuerSpec struct {
// Provisioner contains the Puppet CA certificates provisioner configuration.
Provisioner PuppetCAProvisioner `json:"provisioner"`
}
PuppetCAIssuerSpec defines the desired state of PuppetCAIssuer
func (*PuppetCAIssuerSpec) DeepCopy ¶
func (in *PuppetCAIssuerSpec) DeepCopy() *PuppetCAIssuerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAIssuerSpec.
func (*PuppetCAIssuerSpec) DeepCopyInto ¶
func (in *PuppetCAIssuerSpec) DeepCopyInto(out *PuppetCAIssuerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PuppetCAIssuerStatus ¶
type PuppetCAIssuerStatus struct {
// +optional
Conditions []PuppetCAIssuerCondition `json:"conditions,omitempty"`
}
PuppetCAIssuerStatus defines the observed state of PuppetCAIssuer
func (*PuppetCAIssuerStatus) DeepCopy ¶
func (in *PuppetCAIssuerStatus) DeepCopy() *PuppetCAIssuerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAIssuerStatus.
func (*PuppetCAIssuerStatus) DeepCopyInto ¶
func (in *PuppetCAIssuerStatus) DeepCopyInto(out *PuppetCAIssuerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PuppetCAProvisioner ¶
type PuppetCAProvisioner struct {
// The name of the secret in the pod's namespace to select from.
Name string `json:"secretName"`
// Reference to URL of the Puppet CA
URLRef SecretKeySelector `json:"url"`
// Reference to certificate to access the Puppet CA
CertRef SecretKeySelector `json:"cert"`
// Reference to certificate to access the Puppet CA
KeyRef SecretKeySelector `json:"key"`
// Reference to certificate to access the Puppet CA
CaCertRef SecretKeySelector `json:"cacert"`
}
PuppetCAProvisioner contains the configuration for requesting certificate from the Puppet CA
func (*PuppetCAProvisioner) DeepCopy ¶
func (in *PuppetCAProvisioner) DeepCopy() *PuppetCAProvisioner
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PuppetCAProvisioner.
func (*PuppetCAProvisioner) DeepCopyInto ¶
func (in *PuppetCAProvisioner) DeepCopyInto(out *PuppetCAProvisioner)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SecretKeySelector ¶
type SecretKeySelector struct {
// The key of the secret to select from. Must be a valid secret key.
// +optional
Key string `json:"key,omitempty"`
}
SecretKeySelector contains the reference to a secret.
func (*SecretKeySelector) DeepCopy ¶
func (in *SecretKeySelector) DeepCopy() *SecretKeySelector
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SecretKeySelector.
func (*SecretKeySelector) DeepCopyInto ¶
func (in *SecretKeySelector) DeepCopyInto(out *SecretKeySelector)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.